.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`data`
===================
.. automodule:: skimage.data

.. currentmodule:: skimage.data
.. autosummary::

   skimage.data.astronaut
   skimage.data.binary_blobs
   skimage.data.brick
   skimage.data.camera
   skimage.data.cell
   skimage.data.checkerboard
   skimage.data.chelsea
   skimage.data.clock
   skimage.data.coffee
   skimage.data.coins
   skimage.data.colorwheel
   skimage.data.download_all
   skimage.data.grass
   skimage.data.gravel
   skimage.data.horse
   skimage.data.hubble_deep_field
   skimage.data.immunohistochemistry
   skimage.data.lbp_frontal_face_cascade_filename
   skimage.data.lfw_subset
   skimage.data.load
   skimage.data.logo
   skimage.data.microaneurysms
   skimage.data.moon
   skimage.data.page
   skimage.data.retina
   skimage.data.rocket
   skimage.data.shepp_logan_phantom
   skimage.data.stereo_motorcycle
   skimage.data.text



astronaut
---------

.. autofunction:: skimage.data.astronaut


.. include:: skimage.data.astronaut.examples

binary_blobs
------------

.. autofunction:: skimage.data.binary_blobs


.. include:: skimage.data.binary_blobs.examples

brick
-----

.. autofunction:: skimage.data.brick


.. include:: skimage.data.brick.examples

camera
------

.. autofunction:: skimage.data.camera


.. include:: skimage.data.camera.examples

cell
----

.. autofunction:: skimage.data.cell


.. include:: skimage.data.cell.examples

checkerboard
------------

.. autofunction:: skimage.data.checkerboard


.. include:: skimage.data.checkerboard.examples

chelsea
-------

.. autofunction:: skimage.data.chelsea


.. include:: skimage.data.chelsea.examples

clock
-----

.. autofunction:: skimage.data.clock


.. include:: skimage.data.clock.examples

coffee
------

.. autofunction:: skimage.data.coffee


.. include:: skimage.data.coffee.examples

coins
-----

.. autofunction:: skimage.data.coins


.. include:: skimage.data.coins.examples

colorwheel
----------

.. autofunction:: skimage.data.colorwheel


.. include:: skimage.data.colorwheel.examples

download_all
------------

.. autofunction:: skimage.data.download_all


.. include:: skimage.data.download_all.examples

grass
-----

.. autofunction:: skimage.data.grass


.. include:: skimage.data.grass.examples

gravel
------

.. autofunction:: skimage.data.gravel


.. include:: skimage.data.gravel.examples

horse
-----

.. autofunction:: skimage.data.horse


.. include:: skimage.data.horse.examples

hubble_deep_field
-----------------

.. autofunction:: skimage.data.hubble_deep_field


.. include:: skimage.data.hubble_deep_field.examples

immunohistochemistry
--------------------

.. autofunction:: skimage.data.immunohistochemistry


.. include:: skimage.data.immunohistochemistry.examples

lbp_frontal_face_cascade_filename
---------------------------------

.. autofunction:: skimage.data.lbp_frontal_face_cascade_filename


.. include:: skimage.data.lbp_frontal_face_cascade_filename.examples

lfw_subset
----------

.. autofunction:: skimage.data.lfw_subset


.. include:: skimage.data.lfw_subset.examples

load
----

.. autofunction:: skimage.data.load


.. include:: skimage.data.load.examples

logo
----

.. autofunction:: skimage.data.logo


.. include:: skimage.data.logo.examples

microaneurysms
--------------

.. autofunction:: skimage.data.microaneurysms


.. include:: skimage.data.microaneurysms.examples

moon
----

.. autofunction:: skimage.data.moon


.. include:: skimage.data.moon.examples

page
----

.. autofunction:: skimage.data.page


.. include:: skimage.data.page.examples

retina
------

.. autofunction:: skimage.data.retina


.. include:: skimage.data.retina.examples

rocket
------

.. autofunction:: skimage.data.rocket


.. include:: skimage.data.rocket.examples

shepp_logan_phantom
-------------------

.. autofunction:: skimage.data.shepp_logan_phantom


.. include:: skimage.data.shepp_logan_phantom.examples

stereo_motorcycle
-----------------

.. autofunction:: skimage.data.stereo_motorcycle


.. include:: skimage.data.stereo_motorcycle.examples

text
----

.. autofunction:: skimage.data.text


.. include:: skimage.data.text.examples

